The results of a user query. Able to accept multiple responses
to increase the record count, or to add columns.
Methods
Method from_response_request()
Usage
Query$from_response_request()
Usage
Query$perform(api_key = NULL)
Usage
Query$save_metadata_json(file_path)
Method save_records_csv()
Usage
Query$save_records_csv(file_path, expanded = FALSE)
Method expand_col()
Usage
Query$expand_col(column_name)
Method clone()
The objects of this class are cloneable with this method.
Usage
Query$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.