Learn R Programming

ArctosR (version 0.1.3)

get_last_response_url: Get the last URL used by a request in a query object

Description

Returns the last URL used by a request in a query object

Usage

get_last_response_url(query)

Value

The URL of the last performed request in a query object

Arguments

query

A query object to return the URL for

Examples

Run this code
library(ArctosR)

if (interactive()) {
  query <- get_records(
    scientific_name = "Canis lupus", guid_prefix = "MSB:Mamm",
    columns = list("guid", "parts", "partdetail")
  )

  get_last_response_url(query)
}

Run the code above in your browser using DataLab