Request from Arctos the total number of records that match a specific query.
A list of possible query keys can be obtained from the output of
get_query_parameters.
Examples
library(ArctosR)
if (interactive()) {
count <- get_record_count(
scientific_name = "Canis lupus", guid_prefix = "MSB:Mamm"
)
}