Get the relationships (e.g. "host of") a cataloged item has
Source:R/frontend.R
get_relationships.RdA cataloged item in Arctos can be related to any other number of
items by relationships defined in the code table ctid_references. This
function will return all items related by any such relationship in the table
in a data frame.
Examples
library(ArctosR)
if (interactive()) {
r <- get_relationships("MSB:Mamm:140026")
}