Learn R Programming

ArctosR (version 0.1.3)

get_relationships: Get the relationships (e.g. "host of") a cataloged item has

Description

A cataloged item in Arctos can be related to any other number of items by relationships defined in the code table ctid_references. This function will return all items related by any such relationship in the table in a data frame.

Usage

get_relationships(guid)

Value

a data frame of all related items. This contains URLs

Arguments

guid

The Arctos GUID of the item to query relationships over

Examples

Run this code
library(ArctosR)

if (interactive()) {
  r <- get_relationships("MSB:Mamm:140026")
}

Run the code above in your browser using DataLab