get_relationships: Get the relationships (e.g. "host of") a cataloged item has
Description
A cataloged item in Arctos can be related to any other number of
items by relationships defined in the code table ctid_references. This
function will return all items related by any such relationship in the table
in a data frame.
Usage
get_relationships(guid)
Value
a data frame of all related items. This contains URLs
Arguments
guid
The Arctos GUID of the item to query relationships over